==> ReleaseV1.1.1.zip: winginterfacelibrary/src/Interface/DBInterface/IOrganizationDBService.cs <==
﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.DBRequest;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IOrganizationDBService
    {
        Task<long> CreateOrganizationsAsync(CreateOrganizationsDBRequest request);

        Task<OrganizationDTO> GetOrganizationDetailAsync(GetOrganizationDBRequest request);

        Task<PageCollection<OrganizationDTO>> GetOrganizationPageAsync(PageFilterRequest request);

        Task<List<OrganizationDTO>> SearchOrganizationsAsync(string keyword, string parentCode, OrganizationTypeEnum organizationType);

        Task<long> RemoveOrganizationsAsync(RemoveOrganizationsDBRequest request);

        /// <summary>
        /// 通过 医院类型  找到所有上级机构
        /// </summary>
        /// <param name="name"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> FindAllOrganizationByTypeAsync(string organizationCode);

        /// <summary>
        /// 查询机构列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetOrganizationListAsync(GetOrganizationListDBRequest request);

        /// <summary>
        /// 保存机构信息
        /// </summary>
        /// <param name="code">Id</param>
        /// <param name="model">机构基础信息对象</param>
        /// <param name="canNull">字段是否可置空</param>
        /// <param name="modifyReferralOrgs">是否更新转诊医院</param>
        /// <returns>是否成功</returns>
        Task<bool> SaveOrganizationAsync(string code, OrganizationDTO model, bool canNull = false, bool modifyReferralOrgs = false);

        /// <summary>
        /// 根据机构codes获取机构
        /// </summary>
        /// <param name="organizationCodes"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> FindOrganizationListByCodesAsync(List<string> organizationCodes);

        /// <summary>
        /// 更新组织名称
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateOrganizationNameAsync(UpdateOrganizationNameDBRequest request);

        /// <summary>
        /// 后台管理网站通过已分配管理员获取医院
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<OrganizationDTO>> GetManageOrganizationPageAsync(GetManageOrganizationDBPageRequest request);

        /// <summary>
        /// 查询上级医院集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetParentCorporationsAsync(FindParentCorporationsDBRequest request);

        /// <summary>
        /// 根据rootcode列表查询所有相关机构
        /// </summary>
        /// <param name="rootCodes">父级编码</param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> SearchOrgByRootCodesAsync(List<string> rootCodes);

        /// <summary>
        /// 获取是否开启CMS假数据请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<bool> GetIsOpenFakeDataAsync(string organizationCode);

        /// <summary>
        /// 设置是否开启CMS假数据请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<bool> UpdateIsOpenFakeDataAsync(UpdateIsOpenFakeDataDBRequest updateIsOpenFakeDataDBRequest);

        /// <summary>
        /// CMS首页假数据模块列表请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<IList<StatisticDetailInfoDTO>> GetCMSFakeDataAsync(string organizationCode);

        /// <summary>
        /// CMS首页假数据模块列表请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<bool> UpdateCMSFakeDataAsync(UpdateCMSFakeDataDBRequest updateCMSFakeDataDBRequest);
    }
}

==> ReleaseV1.1.2.zip: winginterfacelibrary/src/Interface/DBInterface/IOrganizationDBService.cs <==
﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.DBRequest;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IOrganizationDBService
    {
        Task<long> CreateOrganizationsAsync(CreateOrganizationsDBRequest request);

        Task<OrganizationDTO> GetOrganizationDetailAsync(GetOrganizationDBRequest request);

        Task<PageCollection<OrganizationDTO>> GetOrganizationPageAsync(PageFilterRequest request);

        Task<List<OrganizationDTO>> SearchOrganizationsAsync(string keyword, string parentCode, OrganizationTypeEnum organizationType);

        Task<long> RemoveOrganizationsAsync(RemoveOrganizationsDBRequest request);

        /// <summary>
        /// 通过 医院类型  找到所有上级机构
        /// </summary>
        /// <param name="name"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> FindAllOrganizationByTypeAsync(string organizationCode);

        /// <summary>
        /// 查询机构列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetOrganizationListAsync(GetOrganizationListDBRequest request);

        /// <summary>
        /// 保存机构信息
        /// </summary>
        /// <param name="code">Id</param>
        /// <param name="model">机构基础信息对象</param>
        /// <param name="canNull">字段是否可置空</param>
        /// <param name="modifyReferralOrgs">是否更新转诊医院</param>
        /// <returns>是否成功</returns>
        Task<bool> SaveOrganizationAsync(string code, OrganizationDTO model, bool canNull = false, bool modifyReferralOrgs = false);

        /// <summary>
        /// 根据机构codes获取机构
        /// </summary>
        /// <param name="organizationCodes"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> FindOrganizationListByCodesAsync(List<string> organizationCodes);

        /// <summary>
        /// 更新组织名称
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateOrganizationNameAsync(UpdateOrganizationNameDBRequest request);

        /// <summary>
        /// 后台管理网站通过已分配管理员获取医院
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<OrganizationDTO>> GetManageOrganizationPageAsync(GetManageOrganizationDBPageRequest request);

        /// <summary>
        /// 查询上级医院集合
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> GetParentCorporationsAsync(FindParentCorporationsDBRequest request);

        /// <summary>
        /// 根据rootcode列表查询所有相关机构
        /// </summary>
        /// <param name="rootCodes">父级编码</param>
        /// <returns></returns>
        Task<List<OrganizationDTO>> SearchOrgByRootCodesAsync(List<string> rootCodes);

        /// <summary>
        /// CMS首页假数据模块列表请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<StatisticDetailSettingDTO> GetCMSFakeDataAsync(string organizationCode);

        /// <summary>
        /// CMS首页假数据模块列表请求
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<bool> UpdateCMSFakeDataAsync(UpdateCMSFakeDataDBRequest updateCMSFakeDataDBRequest);

        /// <summary>
        /// 设置急诊医院编码
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetEmergencyOrganizationAsync(SetEmergencyOrganizationDBRequest request);

        /// <summary>
        /// 设置急诊值班医生编码
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SetEmergencyDoctorAsync(SetEmergencyDoctorDBRequest request);
    }
}
